ALTER procedure "InsertMVResults" (
    CALCTYPE smallint,
    SAMPLEIDENT integer,
    GUID integer,
    WA double precision,
    WR double precision,
    T double precision,
    U double precision,
    PGY double precision,
    QGY double precision,
    IMAX double precision,
    KZAP double precision,
    SQRKFG double precision,
    SQRKFGCALC double precision,
    DUMAX double precision,
    DWDOP double precision,
    WEATHERCONDITIONS integer,
    TEMPERATURE double precision,
    FLAGS integer,
    CRC blob sub_type 0 segment size 48)
returns (
    IDENT integer)
as
BEGIN
 DELETE FROM "MVResults"
 WHERE "CalcType"=:CalcType and "SampleIdent"=:SampleIdent and "GUID"=:GUID;
 Ident=GEN_ID("MVResultsIdent",1);
 INSERT INTO "MVResults" ("Ident","CalcType","SampleIdent","GUID","Wa","Wr",
  "T","U","Pgy","Qgy","Imax","Kzap","sqrKfg","sqrKfgCalc","dUmax","dWdop",
  "WeatherConditions","Temperature","Flags","CRC")
 VALUES (:Ident,:CalcType,:SampleIdent,:GUID,:Wa,:Wr,:T,:U,:Pgy,:Qgy,
  :Imax,:Kzap,:sqrKfg,:sqrKfgCalc,:dUmax,:dWdop,
  :WeatherConditions,:Temperature,:Flags,:CRC);
END;

COMMIT;

SET TERM ^ ;

CREATE OR ALTER trigger "WResultsBeforeUpdateOrInsert" for "WResults"
active before insert or update position 0
AS
DECLARE VARIABLE OwnerGUID INTEGER;
DECLARE VARIABLE Ident INTEGER;
BEGIN
 EXECUTE PROCEDURE "InsertMVResults" (0,NEW."SampleIdent",NEW.GUID,
  NEW."Wa",NEW."Wr",NEW."T",NEW."U",NEW."Pgy",NEW."Qgy",
  NEW."Imax",NEW."Kzap",NEW."sqrKfg",NEW."sqrKfgCalc",NEW."dU",NEW."dWdop",
  NEW."WeatherConditions",NEW."Temperature",NEW."Flags",NEW."CRC")
 RETURNING_VALUES :Ident;

 INSERT INTO "PResultsAdd" ("Ident","Balance",
  "dP_line_cu","dP_line_k","dP_line_crown","dQ_line_cu",
  "dP_tr_cu","dQ_tr_cu","dP_tr_xx","dQ_tr_xx",
  "dP_clr","dQ_clr","Qc",
  "Ptrans","Qtrans","Pnagr","Qnagr",
  "Ptrans_fact","Qtrans_fact","Pnagr_fact","Qnagr_fact",
  "Kzagr","Ssum_tr","Ntr","Psum_motor","Nmotor","Ssum_clr","Nclr",
  "LsumP","LsumC","NLineP","NLineC","NAbonents")
 VALUES (:Ident,0,
  NEW."dPnlin_OnBalance",NEW."dPklin_OnBalance",NEW."dPcrown_OnBalance",NEW."dQnlin_OnBalance",
  NEW."dPntr_OnBalance",NEW."dQntr_OnBalance",NEW."dPxx_OnBalance",NEW."dQxx_OnBalance",
  NEW."dPclr_OnBalance",NEW."dQclr_OnBalance",NEW."Qc_onBalance",
  NEW."Ppotr_OnBalance",NEW."Qpotr_OnBalance",0,0,
  NEW."Ppotr_OnBalance_fact",NEW."Qpotr_OnBalance_fact",0,0,
  NEW."Kzag_OnBalance",NEW."Ssum_tr_OnBalance",NEW."Ntr_OnBalance",0,0,0,0,
  NEW."LsumP_OnBalance",NEW."LsumC_OnBalance",NEW."NLineP_OnBalance",NEW."NLineC_OnBalance",
  NEW."NAbonents_OnBalance");

  if  ((NEW."dPnlin_notBalance" is not null) and (NEW."dPxx_notBalance" is not null ) ) then
 INSERT INTO "PResultsAdd" ("Ident","Balance",
  "dP_line_cu","dP_line_k","dP_line_crown","dQ_line_cu",
  "dP_tr_cu","dQ_tr_cu","dP_tr_xx","dQ_tr_xx",
  "dP_clr","dQ_clr","Qc",
  "Ptrans","Qtrans","Pnagr","Qnagr",
  "Ptrans_fact","Qtrans_fact","Pnagr_fact","Qnagr_fact",
  "Kzagr","Ssum_tr","Ntr","Psum_motor","Nmotor","Ssum_clr","Nclr",
  "LsumP","LsumC","NLineP","NLineC","NAbonents")
 VALUES (:Ident,1,
  NEW."dPnlin_notBalance",NEW."dPklin_notBalance",NEW."dPcrown_notBalance",NEW."dQnlin_notBalance",
  NEW."dPntr_notBalance",NEW."dQntr_notBalance",NEW."dPxx_notBalance",NEW."dQxx_notBalance",
  NEW."dPclr_notBalance",NEW."dQclr_notBalance",NEW."Qc_notBalance",
  NEW."Ppotr_notBalance",NEW."Qpotr_notBalance",0,0,
  NEW."Ppotr_notBalance_fact",NEW."Qpotr_notBalance_fact",0,0,
  NEW."Kzag_notBalance",NEW."Ssum_tr_NotBalance",NEW."Ntr_NotBalance",0,0,0,0,
  NEW."LsumP_NotBalance",NEW."LsumC_NotBalance",NEW."NLineP_NotBalance",NEW."NLineC_NotBalance",
  NEW."NAbonents_NotBalance");


 INSERT INTO "WResultsAdd" ("Ident","Balance",
  "DWa_line_cu","DWa_line_k","DWa_line_crown","DWr_line_cu",
  "DWa_tr_cu","DWr_tr_cu","DWa_tr_xx","DWr_tr_xx",
  "DWa_clr","DWr_clr","Wrc",
  "Wa_trans","Wr_trans","Wa_potr","Wr_potr",
  "Wa_trans_fact","Wr_trans_fact","Wa_potr_fact","Wr_potr_fact")
 VALUES (:Ident,0,
  NEW."DWal_cu_onBalance",NEW."DWal_k_onBalance",NEW."DWal_crown_OnBalance",NEW."DWrl_cu_onBalance",
  NEW."DWcu_onBalance",NEW."DWrcu_onBalance",NEW."DWxx_onBalance",NEW."DWrxx_onBalance",
  NEW."DWaclr_onBalance",NEW."DWrclr_onBalance",NEW."Wrc_onBalance",
  NEW."Wa_potr_onBalance",NEW."Wr_potr_onBalance",0,0,
  NEW."Wa_potr_onBalance_fact",NEW."Wr_potr_onBalance_fact",0,0);

if  ((NEW."DWal_cu_notBalance" is not null) and ( NEW."DWxx_notBalance" is not null ) ) then
 INSERT INTO "WResultsAdd" ("Ident","Balance",
  "DWa_line_cu","DWa_line_k","DWa_line_crown","DWr_line_cu",
  "DWa_tr_cu","DWr_tr_cu","DWa_tr_xx","DWr_tr_xx",
  "DWa_clr","DWr_clr","Wrc",
  "Wa_trans","Wr_trans","Wa_potr","Wr_potr",
  "Wa_trans_fact","Wr_trans_fact","Wa_potr_fact","Wr_potr_fact")
 VALUES (:Ident,1,
   NEW."DWal_cu_notBalance",NEW."DWal_k_notBalance",
   NEW."DWal_crown_notBalance",NEW."DWrl_cu_notBalance",
   NEW."DWcu_notBalance",NEW."DWrcu_notBalance",
   NEW."DWxx_notBalance",NEW."DWrxx_notBalance",
   NEW."DWaclr_notBalance",NEW."DWrclr_notBalance",NEW."Wrc_notBalance",
   NEW."Wa_potr_notBalance",NEW."Wr_potr_notBalance",0,0,
   NEW."Wa_potr_notBalance_fact",NEW."Wr_potr_notBalance_fact",0,0);
END ^

COMMIT ^
SET TERM ; ^

 ALTER TABLE "TotalReportSettings" ADD GUID INTEGER;
COMMIT;
 UPDATE "Version" SET "Major"=3, "Minor"=0, "Release"=22,"Build"=2, "VersionDate"='NOW';
COMMIT;
