Alter trigger "WorkLogWSamplesUpdateTrigger" Inactive;

Commit ;

RECONNECT; 

ALTER DOMAIN DECIMAL_8_3 DROP CONSTRAINT;

Commit ;

ALTER DOMAIN DECIMAL_8_3 ADD CHECK(VALUE IS NULL OR VALUE>=0 AND VALUE<100000);
CREATE DOMAIN "Name52_NOT_NULL" AS VARCHAR(52) NOT NULL COLLATE PXW_CYRL;

Commit ;

Update "Provods" Set "AddStr"='' Where "AddStr" is null;
update RDB$RELATION_FIELDS set
RDB$FIELD_SOURCE = 'DECIMAL_8_3'
where (RDB$FIELD_NAME = 'Snom') and
(RDB$RELATION_NAME = 'CurrentLimitReactorsRef');

CREATE GENERATOR "TypicalLoadCurvesIdentGen";
CREATE TABLE "TypicalLoadCurves" ("Ident" "TIntegerIdent",
  "Name" "Name50_NOT_NULL","Unom" "DECIMAL_6_2_NOT_NULL",
  "LoadType" "YesNo_NOT_NULL",
/* 0-P  Q    */
/* 1-I  cos  */
  "kzap1"     DOUBLE_NOT_NULL_ABOVE_0,"sqrKfg1"   DOUBLE_NOT_NULL_ABOVE_0,
  "kzap2"     DOUBLE_NOT_NULL_ABOVE_0,"sqrKfg2"   DOUBLE_NOT_NULL_ABOVE_0,
  "Comment" "Name50",
 CONSTRAINT "PK_TypicalLoadCurves" PRIMARY KEY ("Ident"),
 CONSTRAINT "FK_TypicalLoadCurvesUnom" FOREIGN KEY ("Unom")
  REFERENCES "Unom" ("Unom"));
CREATE UNIQUE INDEX "TypicalLoadCurvesName" ON "TypicalLoadCurves" ("Name");
GRANT ALL ON "TypicalLoadCurves" TO "rtp3user" ;

Commit ;

CREATE TRIGGER "TypicalLoadCurvesBeforeInsert" FOR "TypicalLoadCurves"
 BEFORE INSERT
AS
BEGIN
 IF (NEW."Ident" IS NULL) THEN
  NEW."Ident" = GEN_ID("TypicalLoadCurvesIdentGen",1);
END;

CREATE PROCEDURE "GetNewTypicalLoadCurveIdent" RETURNS (Ident INTEGER)
AS
BEGIN
 Ident=GEN_ID("TypicalLoadCurvesIdentGen",1);
END;
GRANT EXECUTE ON PROCEDURE "GetNewTypicalLoadCurveIdent" TO "rtp3user";

Commit ;

CREATE TABLE "TypicalLoadCurveValues" ("Ident" "TIntegerIdent",
 "Interval" "SmallInt0_NOT_NULL","Value1" "DOUBLE_NOT_NULL_ABOVE_0",
 "Value2" "DOUBLE_NOT_NULL",
 CONSTRAINT "PK_TypicalLoadCurveValues" PRIMARY KEY ("Ident", "Interval"),
 CONSTRAINT "FK_TypicalLoadCurveValues" FOREIGN KEY ("Ident")
  REFERENCES "TypicalLoadCurves" ("Ident") ON DELETE CASCADE ON UPDATE CASCADE,
 CONSTRAINT "CHK_TypicalLoadCurveValues" CHECK
  (("Value1"<=1) AND ("Value2"<=1) AND ("Value2">=-1)));
GRANT ALL ON "TypicalLoadCurveValues" TO "rtp3user" ;

CREATE TABLE "TypicalLoadCurveSeasonality" ("Ident" "TIntegerIdent" ,
 "Month"  "SmallInt0_NOT_NULL" CHECK ("Month">=1 AND "Month"<=12),
 "Value" "DECIMAL_5_4_1_NOT_NULL",
CONSTRAINT "PK_TypicalLoadCurveSeasonality" PRIMARY KEY ("Ident", "Month"),
CONSTRAINT "FK_TypicalLoadCurveSeasonality_" FOREIGN KEY ("Ident")
 REFERENCES "TypicalLoadCurves" ("Ident") ON DELETE CASCADE ON UPDATE CASCADE);
GRANT ALL ON "TypicalLoadCurveSeasonality" TO "rtp3user" ;

CREATE TABLE "TypicalLoadCurveSamples" ("GUID" "TIntegerIdent","Year" "TIdent",
 "SampleDate" "TSampleDate","LoadType" "YesNo_NOT_NULL","V" "DECIMAL_9_3_NOT_NULL",
 CONSTRAINT "PK_TypicalLoadCurveSamples" PRIMARY KEY (GUID, "Year"),
 CONSTRAINT "FK_TypicalLoadCurveSamplesGUID" FOREIGN KEY (GUID) REFERENCES GUID (GUID)
  ON DELETE CASCADE ON UPDATE CASCADE,
 CONSTRAINT "CHK_TypicalLoadCurveSamplesYear"
  CHECK (EXTRACT(YEAR FROM "SampleDate")="Year"));
GRANT ALL ON "TypicalLoadCurveSamples" TO "rtp3user" ;

Commit ;

CREATE TRIGGER "TypicalLoadCurveSamplesBUI" FOR "TypicalLoadCurveSamples"
BEFORE INSERT OR UPDATE
AS
BEGIN
 NEW."Year"=EXTRACT(YEAR FROM NEW."SampleDate");
END;

CREATE TABLE "LoadCurvesPQ" ("GUID" "TIntegerIdent","SampleTime" "TSampleDate",
  "P" "DOUBLE_NOT_NULL","Q" DOUBLE PRECISION,
 CONSTRAINT "PK_LoadCurvesPQ" PRIMARY KEY ("GUID", "SampleTime"),
 CONSTRAINT "FK_LoadCurvesPQ" FOREIGN KEY ("GUID") REFERENCES "GUID" ("GUID")
  ON DELETE CASCADE ON UPDATE CASCADE);
GRANT ALL ON "LoadCurvesPQ" TO "rtp3user" ;

CREATE TABLE "LoadCurvesU" ("GUID" "TIntegerIdent","SampleTime" "TSampleDate",
 "U" "DOUBLE_ABOVE_0","Temperature" "DECIMAL_Temperature",
 CONSTRAINT "PK_LoadCurvesU" PRIMARY KEY ("GUID", "SampleTime"),
 CONSTRAINT "FK_LoadCurvesU" FOREIGN KEY ("GUID") REFERENCES "GUID" ("GUID")
  ON DELETE CASCADE ON UPDATE CASCADE);
GRANT ALL ON "LoadCurvesU" TO "rtp3user" ;

CREATE GENERATOR "PResultsLCIdent";
CREATE TABLE "PResultsLC" ("Ident" "TIntegerIdent",
 "SampleTime" "TSampleDate","GUID" "TIntegerIdent",
 "P" "DOUBLE_NOT_NULL_ABOVE_0","Q" "DOUBLE_NOT_NULL","U" "DOUBLE_NOT_NULL_ABOVE_0",
 "dUmax" "DOUBLE_NOT_NULL_ABOVE_0","Temperature" "DECIMAL_Temperature_NOT_NULL",
 "Flags" INTEGER,CRC BLOB SUB_TYPE 0 SEGMENT SIZE 48,
CONSTRAINT "PK_PResultsLC" PRIMARY KEY ("Ident"),
CONSTRAINT "FK_PResultsLC_GUID" FOREIGN KEY ("GUID") REFERENCES "Fiders" ("GUID")
 ON DELETE CASCADE ON UPDATE CASCADE);
CREATE UNIQUE INDEX "idxPResultsLC" ON "PResultsLC" ("SampleTime", "GUID");
GRANT ALL ON "PResultsLC" TO "rtp3user";

CREATE TRIGGER "PResultsLCBeforeUpdate" FOR "PResultsLC" BEFORE UPDATE
AS
BEGIN
 IF (NEW."SampleTime"<>OLD."SampleTime" OR NEW.GUID<>OLD.GUID OR
     NEW.P<>OLD.P OR NEW.Q<>OLD.Q OR NEW.U<>OLD.U OR NEW."dUmax"<>OLD."dUmax" OR
     NEW."Temperature"<>OLD."Temperature" OR NEW."Flags"<>OLD."Flags")
 THEN EXCEPTION "NoRelease";
END;

Commit ;

CREATE PROCEDURE "InsertPResultsLC" (SampleTime TIMESTAMP,GUID INTEGER,
 P DOUBLE PRECISION,Q DOUBLE PRECISION,U DOUBLE PRECISION,
 dUmax DOUBLE PRECISION,Temperature DOUBLE PRECISION,Flags INTEGER,
 CRC BLOB SUB_TYPE 0 SEGMENT SIZE 48)
RETURNS (Ident INTEGER)
AS
BEGIN
 DELETE FROM "PResultsLC"
 WHERE "SampleTime"=:SampleTime AND "GUID"=:GUID;
 Ident=GEN_ID("PResultsLCIdent",1);
 INSERT INTO "PResultsLC" ("Ident","SampleTime","GUID",
  "P","Q","U","dUmax","Temperature","Flags","CRC")
 VALUES (:Ident,:SampleTime,:GUID,:P,:Q,:U,:dUmax,:Temperature,:Flags,:CRC);
END ;
GRANT EXECUTE ON PROCEDURE "InsertPResultsLC" TO "rtp3user" ;

CREATE TABLE "PResultsLCAdd" ("Ident" "TIntegerIdent","Balance" "TIdent",
  "dP_line_cu" "DOUBLE_NOT_NULL_ABOVE_0","dP_line_k" "DOUBLE_NOT_NULL_ABOVE_0",
  "dP_line_crown" "DOUBLE_ABOVE_0","dQ_line_cu" "DOUBLE_NOT_NULL_ABOVE_0",
  "dP_tr_cu" "DOUBLE_NOT_NULL_ABOVE_0","dQ_tr_cu" "DOUBLE_NOT_NULL_ABOVE_0",
  "dP_tr_xx" "DOUBLE_NOT_NULL_ABOVE_0","dQ_tr_xx" "DOUBLE_NOT_NULL_ABOVE_0",
  "dP_clr" "DOUBLE_NOT_NULL_ABOVE_0","dQ_clr" "DOUBLE_NOT_NULL_ABOVE_0",
  "Qc" "DOUBLE_NOT_NULL_ABOVE_0",
  "Ptrans" "DOUBLE_NOT_NULL_ABOVE_0","Qtrans" "DOUBLE_NOT_NULL",
  "Pnagr" "DOUBLE_NOT_NULL_ABOVE_0","Qnagr" "DOUBLE_NOT_NULL",
  "Ptrans_fact" "DOUBLE_ABOVE_0","Qtrans_fact" DOUBLE PRECISION,
  "Pnagr_fact" "DOUBLE_ABOVE_0","Qnagr_fact" DOUBLE PRECISION,
  "Kzagr" "DOUBLE_NOT_NULL_ABOVE_0",
  "Ssum_tr" "DECIMAL_10_3_NOT_NULL","Ntr" "SmallInt0_NOT_NULL",
  "Psum_motor" "DECIMAL_10_3_NOT_NULL","Nmotor" "SmallInt0_NOT_NULL",
  "Ssum_clr" "DECIMAL_10_3_NOT_NULL","Nclr" "SmallInt0_NOT_NULL",

  "LsumP" "DECIMAL_9_3_NOT_NULL","LsumC" "DECIMAL_9_3_NOT_NULL",
  "NLineP" "SmallInt0_NOT_NULL","NLineC" "SmallInt0_NOT_NULL",
  "NAbonents" "SmallInt0",
 CONSTRAINT "PK_PResultsLCAdd" PRIMARY KEY ("Ident","Balance"),
 CONSTRAINT "FK_PResultsLCAdd" FOREIGN KEY ("Ident")
  REFERENCES "PResultsLC" ("Ident") ON DELETE CASCADE ON UPDATE CASCADE,
 CONSTRAINT "FK_PResultsLCAddBalance" FOREIGN KEY ("Balance")
  REFERENCES "Owners" ("Ident"));
GRANT ALL ON "PResultsLCAdd" TO "rtp3user" ;

CREATE TRIGGER "PResultsLCAddBeforeUpdate" FOR "PResultsLCAdd" BEFORE UPDATE
AS
BEGIN
 EXCEPTION "NoRelease";
END;

Commit ;

CREATE GENERATOR "WResultsLCIdent";
CREATE TABLE "WResultsLC" ("Ident" "TIntegerIdent",
  "SampleIdent" "TIntegerIdent","GUID" "TIntegerIdent",
  "Wa" "DOUBLE_NOT_NULL_ABOVE_0","Wr" "DOUBLE_NOT_NULL","T" "DECIMAL_8_3",
  "U" "DOUBLE_NOT_NULL_ABOVE_0","Kzap" "DOUBLE_ABOVE_0","sqrKfg" "DOUBLE_ABOVE_0",
  "dUmax" "DOUBLE_NOT_NULL_ABOVE_0",
  "dWdop" "DECIMAL_10_3",
  "Temperature" "DECIMAL_Temperature_NOT_NULL",
  "Flags" INTEGER,"CRC" BLOB SEGMENT SIZE 48,
 CONSTRAINT "PK_WResultsLC" PRIMARY KEY ("Ident"),
 CONSTRAINT "FK_WResultsLC_SampleIdent" FOREIGN KEY ("SampleIdent")
  REFERENCES "SamplesDates" ("Ident") ON DELETE CASCADE ON UPDATE CASCADE,
 CONSTRAINT "FK_WResultsLC_GUID" FOREIGN KEY ("GUID")
  REFERENCES "Fiders" ("GUID") ON DELETE CASCADE ON UPDATE CASCADE) ;
CREATE UNIQUE INDEX "idxWResultsLC" ON "WResultsLC" ("SampleIdent","GUID");
GRANT ALL ON "WResultsLC" TO "rtp3user" ;

CREATE TRIGGER "WResultsLCBeforeUpdate" FOR "WResultsLC" BEFORE UPDATE
AS
BEGIN
 IF (OLD."SampleIdent"<>NEW."SampleIdent" OR OLD.GUID<>NEW.GUID OR
     OLD."Wa"<>NEW."Wa" OR OLD."Wr"<>NEW."Wr" OR OLD.U<>NEW.U OR OLD.T<>NEW.T OR
     OLD."Kzap"<>NEW."Kzap" OR OLD."sqrKfg"<>NEW."sqrKfg" OR
     OLD."dUmax"<>NEW."dUmax" OR OLD."dWdop"<>NEW."dWdop" OR
     OLD."Temperature"<>NEW."Temperature" OR OLD."Flags"<>NEW."Flags")
 THEN EXCEPTION "NoRelease";
END;

Commit ;

CREATE PROCEDURE "InsertWResultsLC" (SampleIdent INTEGER,GUID INTEGER,
 Wa DOUBLE PRECISION,Wr DOUBLE PRECISION,U DOUBLE PRECISION,T DOUBLE PRECISION,
 Kzap DOUBLE PRECISION,sqrKfg DOUBLE PRECISION,
 dUmax DOUBLE PRECISION,dWdop DOUBLE PRECISION,
 Temperature DOUBLE PRECISION,Flags INTEGER,
 CRC BLOB SUB_TYPE 0 SEGMENT SIZE 48)
RETURNS (Ident INTEGER)
AS
BEGIN
 DELETE FROM "WResultsLC"
 WHERE "SampleIdent"=:SampleIdent AND "GUID"=:GUID;
 Ident=GEN_ID("WResultsLCIdent",1);
 INSERT INTO "WResultsLC" ("Ident","SampleIdent","GUID","Wa","Wr","U",
  "T","Kzap","sqrKfg","dUmax","dWdop",
  "Temperature","Flags","CRC")
 VALUES (:Ident,:SampleIdent,:GUID,:Wa,:Wr,:U,:T,:Kzap,:sqrKfg,:dUmax,:dWdop,
  :Temperature,:Flags,:CRC);
END ;
GRANT EXECUTE ON PROCEDURE "InsertWResultsLC" TO "rtp3user" ;

CREATE TABLE "WResultsLCAdd" ("Ident" "TIntegerIdent" ,"Balance" "TIdent",
  "DWa_line_cu" "DOUBLE_NOT_NULL_ABOVE_0","DWa_line_k" "DOUBLE_NOT_NULL_ABOVE_0",
  "DWa_line_crown" "DOUBLE_ABOVE_0","DWr_line_cu" "DOUBLE_NOT_NULL_ABOVE_0",
  "DWa_tr_cu" "DOUBLE_NOT_NULL_ABOVE_0","DWr_tr_cu" "DOUBLE_NOT_NULL_ABOVE_0",
  "DWa_tr_xx" "DOUBLE_NOT_NULL_ABOVE_0","DWr_tr_xx" "DOUBLE_NOT_NULL_ABOVE_0",
  "DWa_clr" "DOUBLE_NOT_NULL_ABOVE_0","DWr_clr" "DOUBLE_NOT_NULL_ABOVE_0",
  "Wrc" "DOUBLE_NOT_NULL_ABOVE_0",
  "Wa_trans" "DOUBLE_NOT_NULL_ABOVE_0","Wr_trans" "DOUBLE_NOT_NULL",
  "Wa_potr" "DOUBLE_NOT_NULL_ABOVE_0","Wr_potr" "DOUBLE_NOT_NULL",
  "Wa_trans_fact" "DOUBLE_ABOVE_0","Wr_trans_fact" DOUBLE PRECISION,
  "Wa_potr_fact" "DOUBLE_ABOVE_0","Wr_potr_fact" DOUBLE PRECISION,

  "Kzagr" "DOUBLE_NOT_NULL_ABOVE_0",
  "Ssum_tr" "DECIMAL_10_3_NOT_NULL","Ntr" "SmallInt0_NOT_NULL",
  "Psum_motor" "DECIMAL_10_3_NOT_NULL","Nmotor" "SmallInt0_NOT_NULL",
  "Ssum_clr" "DECIMAL_10_3_NOT_NULL","Nclr" "SmallInt0_NOT_NULL",
  "LsumP" "DECIMAL_9_3_NOT_NULL","LsumC" "DECIMAL_9_3_NOT_NULL",
  "NLineP" "SmallInt0_NOT_NULL","NLineC" "SmallInt0_NOT_NULL",
  "NAbonents" "SmallInt0",
 CONSTRAINT "PK_WResultsLCAdd" PRIMARY KEY ("Ident","Balance"),
 CONSTRAINT "FK_WResultsLCAddIdent" FOREIGN KEY ("Ident")
  REFERENCES "WResultsLC" ("Ident") ON DELETE CASCADE ON UPDATE CASCADE,
 CONSTRAINT "FK_WResultsLCAddBalance" FOREIGN KEY ("Balance")
  REFERENCES "Owners" ("Ident") ON UPDATE CASCADE);
GRANT ALL ON "WResultsLCAdd" TO "rtp3user" ;

Commit ;

CREATE TRIGGER "WResultsLCAddBeforeUpdate" FOR "WResultsLCAdd" BEFORE UPDATE
AS
BEGIN
 EXCEPTION "NoRelease";
END;

CREATE TRIGGER "LoadCurvesPQAfterUpdate" FOR "LoadCurvesPQ" AFTER INSERT OR UPDATE
AS
BEGIN
 DELETE FROM "PResultsLC" R
 WHERE "SampleTime"=NEW."SampleTime" AND
  (EXISTS(SELECT * FROM "Nodes" N
          WHERE R.GUID=N."OwnerGUID" AND N."GUID"=NEW."GUID"));
END;

CREATE TRIGGER "LoadCurvesPQBeforeDelete" FOR "LoadCurvesPQ" BEFORE DELETE
AS
BEGIN
 DELETE FROM "PResultsLC" R
 WHERE "SampleTime"=OLD."SampleTime" AND
  (EXISTS(SELECT * FROM "Nodes" N
          WHERE R.GUID=N."OwnerGUID" AND N."GUID"=OLD."GUID"));
END;

Commit ;

CREATE TRIGGER "PResultsLCAfterInsert" FOR "PResultsLC" AFTER INSERT
AS
BEGIN
 DELETE FROM "WResultsLC"
 WHERE "Ident" IN
  (SELECT W."Ident" FROM "WResultsLC" W
   INNER JOIN "SamplesDates" D ON D."Ident"=W."SampleIdent"
   WHERE W."GUID"=NEW."GUID" AND
    D."SampleDate1"<=NEW."SampleTime" AND D."SampleDate2">NEW."SampleTime");
END;

CREATE TRIGGER "PResultsLCBeforeDelete" FOR "PResultsLC" BEFORE DELETE
AS
BEGIN
DELETE FROM "WResultsLC"
 WHERE "Ident" IN
  (SELECT W."Ident" FROM "WResultsLC" W
   INNER JOIN "SamplesDates" D ON D."Ident"=W."SampleIdent"
   WHERE W."GUID"=OLD."GUID" AND
    D."SampleDate1"<=OLD."SampleTime" AND D."SampleDate2">OLD."SampleTime");
END;

CREATE TRIGGER "WorkLogLoadCurvesPQUpdate" FOR "LoadCurvesPQ" AFTER INSERT OR UPDATE
AS
DECLARE VARIABLE oGUID INTEGER;
DECLARE VARIABLE AFiderName VARCHAR(130);
BEGIN
 SELECT "OwnerGUID" FROM "Nodes" WHERE "GUID"=NEW."GUID" INTO oGUID;
 IF (oGUID IS NOT NULL) THEN
  BEGIN
   SELECT ': '||"Centers"."Name"||' : '||"Fiders"."Name" FROM "Fiders"
   INNER JOIN "Sections" ON ("Sections"."GUID"="Fiders"."OwnerGUID")
   INNER JOIN "Centers" ON ("Centers"."GUID"="Sections"."OwnerGUID")
   WHERE "Fiders"."GUID"=:oGUID
   INTO AFiderName;

   INSERT INTO "WorkLog" ("FiderName","EventIdent","SampleDate")
   VALUES (:AFiderName,201,NEW."SampleTime");
 END
END;

CREATE TRIGGER "WorkLogLoadCurvesPQDelete" FOR "LoadCurvesPQ" BEFORE DELETE
AS
DECLARE VARIABLE oGUID INTEGER;
DECLARE VARIABLE AFiderName VARCHAR(130);
BEGIN
 SELECT "OwnerGUID" FROM "Nodes" WHERE "GUID"=OLD."GUID" INTO oGUID;
 IF (oGUID IS NOT NULL) THEN
  BEGIN
   SELECT ': '||"Centers"."Name"||' : '||"Fiders"."Name" FROM "Fiders"
   INNER JOIN "Sections" ON ("Sections"."GUID"="Fiders"."OwnerGUID")
   INNER JOIN "Centers" ON ("Centers"."GUID"="Sections"."OwnerGUID")
   WHERE "Fiders"."GUID"=:oGUID
   INTO AFiderName;

   INSERT INTO "WorkLog" ("FiderName","EventIdent","SampleDate")
   VALUES (:AFiderName,202,OLD."SampleTime");
 END
END;

CREATE TRIGGER "WorkLogPResultsLCInsert" FOR "PResultsLC" AFTER UPDATE
AS
DECLARE VARIABLE AFiderName VARCHAR(130);
BEGIN
 IF (NEW."GUID"<>0) THEN
  BEGIN
   SELECT ': '||"Centers"."Name"||' : '||"Fiders"."Name" FROM "Fiders"
   INNER JOIN "Sections" ON ("Sections"."GUID"="Fiders"."OwnerGUID")
   INNER JOIN "Centers" ON ("Centers"."GUID"="Sections"."OwnerGUID")
   WHERE "Fiders"."GUID"=NEW."GUID"
   INTO AFiderName;

   INSERT INTO "WorkLog" ("FiderName","EventIdent","SampleDate")
   VALUES (:AFiderName,203,NEW."SampleTime");
 END
END;

CREATE TRIGGER "WorkLogPResultsLCDelete" FOR "PResultsLC" BEFORE DELETE
AS
DECLARE VARIABLE AFiderName VARCHAR(130);
BEGIN
 IF (OLD."GUID"<>0) THEN
  BEGIN
   SELECT ': '||"Centers"."Name"||' : '||"Fiders"."Name" FROM "Fiders"
   INNER JOIN "Sections" ON ("Sections"."GUID"="Fiders"."OwnerGUID")
   INNER JOIN "Centers" ON ("Centers"."GUID"="Sections"."OwnerGUID")
   WHERE "Fiders"."GUID"=OLD."GUID"
   INTO AFiderName;

   INSERT INTO "WorkLog" ("FiderName","EventIdent","SampleDate")
   VALUES (:AFiderName,204,OLD."SampleTime");
 END
END;

CREATE TRIGGER "WorkLogWResultsLCInsert" FOR "WResultsLC" AFTER INSERT
AS
DECLARE VARIABLE AFiderName VARCHAR(130);
DECLARE VARIABLE ASampleDate VARCHAR(50);
BEGIN
 IF (NEW."GUID"<>0) THEN
  BEGIN
   SELECT ': '||"Centers"."Name"||' : '||"Fiders"."Name" FROM "Fiders"
   INNER JOIN "Sections" ON ("Sections"."GUID"="Fiders"."OwnerGUID")
   INNER JOIN "Centers" ON ("Centers"."GUID"="Sections"."OwnerGUID")
   WHERE "Fiders"."GUID"=NEW."GUID"
   INTO AFiderName;

   SELECT "Name" FROM "SamplesDates"
   WHERE "Ident"=NEW."SampleIdent"
   INTO ASampleDate;

   INSERT INTO "WorkLog" ("FiderName","EventIdent","SampleDate")
   VALUES (:AFiderName,205,:ASampleDate);
 END
END;

CREATE TRIGGER "WorkLogWResultsLCDelete" FOR "WResultsLC" BEFORE DELETE
AS
DECLARE VARIABLE AFiderName VARCHAR(130);
DECLARE VARIABLE ASampleDate VARCHAR(50);
BEGIN
 IF (OLD."GUID"<>0) THEN
  BEGIN
   SELECT ': '||"Centers"."Name"||' : '||"Fiders"."Name" FROM "Fiders"
   INNER JOIN "Sections" ON ("Sections"."GUID"="Fiders"."OwnerGUID")
   INNER JOIN "Centers" ON ("Centers"."GUID"="Sections"."OwnerGUID")
   WHERE "Fiders"."GUID"=OLD."GUID"
   INTO AFiderName;

   SELECT "Name" FROM "SamplesDates"
   WHERE "Ident"=OLD."SampleIdent"
   INTO ASampleDate;

   INSERT INTO "WorkLog" ("FiderName","EventIdent","SampleDate")
   VALUES (:AFiderName,206,:ASampleDate);
 END
END;

ALTER TABLE "LVConsumers" ADD "TypicalLoadCurve" INTEGER;
ALTER TABLE "LVConsumers" ADD CONSTRAINT "FK_LVConsumers_TypicalLoadCurve"
FOREIGN KEY ("TypicalLoadCurve") REFERENCES "TypicalLoadCurves" ("Ident")
ON UPDATE CASCADE ON DELETE SET NULL;

ALTER TABLE "LVWLoads" ADD "SampleType" SMALLINT;
ALTER TABLE "LVWLoads" ALTER COLUMN "Wa" TYPE DECIMAL_9_3;
ALTER TABLE "LVWLoads" ADD CHECK("SampleType" IS NULL OR "SampleType" IN (0,3,4));

ALTER TABLE "Nodes" ADD "TypicalLoadCurve" INTEGER;
ALTER TABLE "Nodes" ADD CONSTRAINT "FK_Nodes_TypicalLoadCurve"
FOREIGN KEY ("TypicalLoadCurve") REFERENCES "TypicalLoadCurves" ("Ident")
ON UPDATE CASCADE ON DELETE SET NULL;
ALTER TABLE "Nodes3" ADD "TypicalLoadCurveCH" INTEGER;
ALTER TABLE "Nodes3" ADD CONSTRAINT "FK_Nodes3_TypicalLoadCurve"
FOREIGN KEY ("TypicalLoadCurveCH") REFERENCES "TypicalLoadCurves" ("Ident")
ON UPDATE CASCADE ON DELETE SET NULL;

/*ALTER TABLE "SamplesDates" ALTER COLUMN "Name" TYPE "Name52_NOT_NULL"; */
update RDB$RELATION_FIELDS set RDB$FIELD_SOURCE = 'Name52_NOT_NULL'
where (RDB$FIELD_NAME = 'Name') and (RDB$RELATION_NAME = 'SamplesDates');

ALTER PROCEDURE "InsertSamplesDates"(Name varchar(52),Period smallint,
 SampleDate1 TIMESTAMP,SampleDate2 TIMESTAMP,Temperature DECIMAL(5,2),
 WeatherConditions INTEGER)
RETURNS (Ident Integer)
AS
BEGIN
  Ident=GEN_ID("SamplesDateIdent",1);
 INSERT INTO "SamplesDates"
  ("Ident","Name","Period","SampleDate1","SampleDate2","Temperature","WeatherConditions")
 VALUES (:Ident,:Name,:Period,:SampleDate1,:SampleDate2,:Temperature,:WeatherConditions);
END;

ALTER TABLE "WLoads" ADD "SampleType" "TIdent" DEFAULT 0;
ALTER TABLE "WLoads" ALTER COLUMN "Wa" TYPE DECIMAL_11_3;

ALTER TABLE "Sections" ADD CONSTRAINT "UNQ_Sections" UNIQUE ("OwnerGUID", "Name", "Unom");


Commit ;


CREATE TRIGGER "WorkLogPResultsLCInsert" FOR "PResultsLC"
ACTIVE AFTER INSERT POSITION 0 
AS
DECLARE VARIABLE AFiderName VARCHAR(130);
BEGIN
 IF (NEW."GUID"<>0) THEN
  BEGIN
   SELECT ': '||"Centers"."Name"||' : '||"Fiders"."Name" FROM "Fiders"
   INNER JOIN "Sections" ON ("Sections"."GUID"="Fiders"."OwnerGUID")
   INNER JOIN "Centers" ON ("Centers"."GUID"="Sections"."OwnerGUID")
   WHERE "Fiders"."GUID"=NEW."GUID"
   INTO AFiderName;

   INSERT INTO "WorkLog" ("FiderName","EventIdent","SampleDate")
   VALUES (:AFiderName,203,NEW."SampleTime");
 END
END ;


Commit ;

Set term ^;

Commit ^

CREATE OR ALTER PROCEDURE "InsertTransformVRef" (
 Indication VARCHAR(40),AccuracyClass SMALLINT,Unom DECIMAL(10,2),
 UnomB INTEGER,UnomH DECIMAL(10,2),VoltageDrop DECIMAL(10,2),
 PrefailureLife INTEGER,WorkTemperatureLow SMALLINT,WorkTemperatureHigh SMALLINT,
 Manufacturer SMALLINT,Hide SMALLINT)
RETURNS (Ident INTEGER)
AS
BEGIN
 Ident=GEN_ID("ReferenceIdent",1);
 INSERT INTO "TransformsVRef"
  ("Ident","Indication","AccuracyClass","Unom","UnomB","UnomH","VoltageDrop",
   "PrefailureLife","WorkTemperatureLow","WorkTemperatureHigh",
   "Manufacturer","Hide")
  VALUES (:Ident,:Indication,:AccuracyClass,:Unom,:UnomB,:UnomH,:VoltageDrop,
   :PrefailureLife,:WorkTemperatureLow,:WorkTemperatureHigh,
   :Manufacturer,:Hide);
END ^

Commit ^

Set Term ;^ 

CREATE TRIGGER "LVWLoadsAfterUpdate" FOR "LVWLoads"
ACTIVE AFTER INSERT OR UPDATE POSITION 0
AS
BEGIN
 IF (NEW."SampleIdent"=0 AND NEW."Wa" IS NULL) THEN
  DELETE FROM "LVWLoads" WHERE "GUID"=NEW."GUID" AND "SampleIdent"=NEW."SampleIdent";
END;

CREATE TRIGGER "WLoadsAfterUpdate" FOR "WLoads"
ACTIVE AFTER INSERT OR UPDATE POSITION 0
AS
BEGIN
 if (NEW."SampleType"=0 and NEW."Wa" is null) then
  delete from "WLoads" where "GUID"=NEW."GUID" and "SampleIdent"=NEW."SampleIdent";
END;

COMMIT;

 ALTER TABLE "TotalReportSettings" ADD GUID INTEGER;

 Insert into "Unom" ("Unom") Values (0.6);
COMMIT;

ALTER TABLE "InitParams" DROP CONSTRAINT "CHK_InitParams_Values";
COMMIT;
ALTER TABLE "InitParams" ADD "TEMP$$Value" DOUBLE_NOT_NULL;
COMMIT;
UPDATE "InitParams"  SET "TEMP$$Value"="Value";
COMMIT;
ALTER TABLE "InitParams" DROP "Value";
COMMIT;
ALTER TABLE "InitParams" ALTER COLUMN "TEMP$$Value" TO "Value";
COMMIT;
ALTER TABLE "InitParams" ADD CONSTRAINT "CHK_InitParams_Values" CHECK(("Key"=1) and ("Value" between 0 and 1) or /* smCosFi */
 ("Key"=2 or "Key"=3) and ("Value" between "Param"*0.8 and "Param"*1.2) or /* smUcp, smUdop*/
 ("Key"=4) and ("Value" between 1/13 and 1) or /* smKzap */
 ("Key"=6) and ("Value" between 0.04 and 1) or /* smTau */
 ("Key"=7) and ("Value">0) or /* smCurrentDensityLimit */

 ("Key" in (100,108,109,110,111) and "Value" between -2147483647 and 2147483647) or /*(smAOEnergoGUID,smVNCalc,smNNCalc,smStLoads,smMetrolog */
 ("Key"=101 and "Value" between 1 and 7) or /*smRegionIdent */
 ("Key"=102 and "Value" between 1 and 3) or /* smKdp */
 ("Key" in (103,105,112,113,114,115) and ("Value"=0 or "Value"=1)) or /* (smUseTemperature,smKuntp,smDotDisableLine,smShowPhases */
 ("Key"=104 and "Value" between -70 and 70) or /* smTemperature */
 ("Key" in (106,107,116) and ("Value" between 0 and 2)  or /* smSaveDetailed,smSaveDetailedHH,smShowArrowDirection */
 ("Key"=5 or "Key"=200 or "Key"=201) and ("Value" between -2147483.648 and 2147483.647) /* Colors */));
COMMIT;

 ALTER EXCEPTION "TransfUnomError"  '   '; 
 COMMIT; 

ALTER TABLE "WLoadsGenerators" ALTER COLUMN "Wa" TYPE NUMBER_11_3;
COMMIT;

SET TERM ^ ;
ALTER PROCEDURE "InsertCurrentLimitReactorRef"(MARKA VARCHAR(32),
SNOM DECIMAL(11,3),UNOM DECIMAL(10,2),INOM DECIMAL(10,2),
DP DECIMAL(10,2),X DECIMAL(10,4),ISDOUBLE SMALLINT,KSV DECIMAL(10,3),
MANUFACTURER SMALLINT,HIDE SMALLINT)
RETURNS(IDENT INTEGER)
AS BEGIN SUSPEND; END
^

ALTER TABLE "CurrentLimitReactorsRef" ALTER COLUMN "Snom" TYPE DECIMAL_11_3_NOT_NULL^

ALTER PROCEDURE "InsertCurrentLimitReactorRef"(MARKA VARCHAR(32),
SNOM DECIMAL(11,3),
UNOM DECIMAL(10,2),
INOM DECIMAL(10,2),
DP DECIMAL(10,2),
X DECIMAL(10,4),
ISDOUBLE SMALLINT,
KSV DECIMAL(10,3),
MANUFACTURER SMALLINT,
HIDE SMALLINT)
 RETURNS(IDENT INTEGER)
 AS
BEGIN
 Ident=GEN_ID("ReferenceIdent",1);
 INSERT INTO "CurrentLimitReactorsRef"
  ("Ident","Marka","Snom","Unom","Inom","dP","X","isDouble","Ksv","Manufacturer","Hide")
 VALUES (:Ident,:Marka,:Snom,:Unom,:Inom,:dP,:X,:isDouble,:Ksv,:Manufacturer,:Hide);
END
^
COMMIT ^ 

DROP TRIGGER "WorkLogPResultsLCInsert" ^

COMMIT ^ 

CREATE TRIGGER "WorkLogPResultsLCInsert" FOR "PResultsLC"
ACTIVE AFTER INSERT POSITION 0
AS
DECLARE VARIABLE AFiderName VARCHAR(130);
BEGIN
 IF (NEW."GUID"<>0) THEN
  BEGIN
   SELECT 'OI: '||"Centers"."Name"||' Oeaa?: '||"Fiders"."Name" FROM "Fiders"
   INNER JOIN "Sections" ON ("Sections"."GUID"="Fiders"."OwnerGUID")
   INNER JOIN "Centers" ON ("Centers"."GUID"="Sections"."OwnerGUID")
   WHERE "Fiders"."GUID"=NEW."GUID"
   INTO AFiderName;

   INSERT INTO "WorkLog" ("FiderName","EventIdent","SampleDate")
   VALUES (:AFiderName,203,NEW."SampleTime");
 END
END
^

COMMIT^

CREATE TRIGGER "AOEnergoAfterUpdate" FOR "AOEnergo"
ACTIVE AFTER UPDATE POSITION 0
AS
BEGIN
 if (NEW."Region"<>OLD."Region") then
  delete from "MVResults" where "Ident" in
   (select distinct MVR."Ident" from "Fiders" F
    inner join "Sections" S on F."OwnerGUID"=S.GUID
    inner join "Centers" C on S."OwnerGUID"=C.GUID
    inner join "RES" R on C."OwnerGUID"=R.GUID
    inner join "PES" P on R."OwnerGUID"=P.GUID
    inner join "MVResults" MVR on MVR.GUID=F.GUID
    left outer join "PResultsAdd" PR on PR."Ident"=MVR."Ident"
    left outer join "WResultsAdd" WR on WR."Ident"=MVR."Ident"
    where P."OwnerGUID"=NEW."GUID" and (PR."dP_line_crown">0 or WR."DWa_line_crown">0));

 UPDATE "IntStLoads" SET "IntStLoads"."Name"=new."Name" WHERE "IntStLoads"."OwnerGUID"=new.guid ;
END
^

COMMIT^

/**SET TERM ^ ;  **/

ALTER TABLE "LVWSamples" ALTER COLUMN "Wa" TYPE DECIMAL_9_3^
ALTER TABLE "WSamples" ALTER COLUMN "Wa" TYPE DECIMAL_11_3^

update RDB$RELATION_FIELDS set
RDB$FIELD_SOURCE = 'DECIMAL_8_3'
where (RDB$FIELD_NAME = 'Snom') and
(RDB$RELATION_NAME = 'CurrentLimitReactorsRef')^

COMMIT^
update "WSamples" set "SampleType"=2,"Wa"=0 where "Wa"<0^
delete from "WLoads" where "Wa"<0^
delete from "LVWLoads" where "Wa"<0^

COMMIT^

 Alter trigger "WorkLogWSamplesUpdateTrigger" Inactive^

COMMIT^
 UPDATE "Version" SET "Major"=4, "Minor"=0, "Release"=23,"Build"=0, "VersionDate"='NOW'^
COMMIT^
